import Combine
import SwiftUI

final class VM: ObservableObject {
  @Published var text = "a:"
  
  var subscriptions = Set<AnyCancellable>()

  init() {
      $text
          // Исключаем конфликты от UI и App путём игнорирования спама.
          .debounce(for: .seconds(0.3), scheduler: DispatchQueue.main)
          // Нужны лишь значения от UI.
          .filter { $0.hasPrefix("u:") }
          // Убираем источник.
          .map { String($0.dropFirst(2)) }
          .sink { Bus.send(MeetupId.Keys.meetupIdTextUI.rawValue, $0) }
          .store(in: &subscriptions)

      Bus.receiveAsync(
        &subscriptions,
        [MeetupId.Keys.meetupIdTextApp.rawValue],
        { [weak self] (_, v: String) in self?.text = "a:\(v)" }
      )
  }
}
